Interface: BorderRadius | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: BorderRadius

## # Properties

### # bottomLeft

• bottomLeft: `number`

#### # Defined in

index.esm.d.ts:2021
(opens new window)

### # bottomRight

• bottomRight: `number`

#### # Defined in

index.esm.d.ts:2022
(opens new window)

### # topLeft

• topLeft: `number`

#### # Defined in

index.esm.d.ts:2019
(opens new window)

### # topRight

• topRight: `number`

#### # Defined in

index.esm.d.ts:2020
(opens new window)